==> cds-services-impl-2.0.1-sources.jar: com/sap/cds/services/impl/draft/DraftReadEventContextImpl.java <==
/**************************************************************************
 * (C) 2019-2021 SAP SE or an SAP affiliate company. All rights reserved. *
 **************************************************************************/
package com.sap.cds.services.impl.draft;

import java.util.Map;

import com.sap.cds.Result;
import com.sap.cds.ql.cqn.CqnSelect;
import com.sap.cds.services.EventContext;
import com.sap.cds.services.draft.DraftService;
import com.sap.cds.services.impl.EventContextDelegator;
import com.sap.cds.services.utils.ResultUtils;

/**
 * Implementation for specialized {@link EventContext} to be used for {@link DraftServiceImpl#EVENT_DRAFT_READ}
 */
public class DraftReadEventContextImpl extends EventContextDelegator implements DraftReadEventContext {

	public DraftReadEventContextImpl(EventContext eventContext) {
		super(eventContext);
	}

	@Override
	public DraftService getService() {
		return (DraftService) super.getService();
	}

	private static final String PARAM_CQN = "cqn";
	private static final String PARAM_CQN_NAME_VALUES = "cqnNamedValues";
	private static final String PARAM_RESULT = "result";

	// IN
	public CqnSelect getCqn() {
		return (CqnSelect)get(PARAM_CQN);
	}

	public void setCqn(CqnSelect cqn) {
		put(PARAM_CQN, cqn);
	}

	@SuppressWarnings("unchecked")
	public Map<String, Object> getCqnNamedValues(){
		return (Map<String,Object>)get(PARAM_CQN_NAME_VALUES);
	}

	public void setCqnNamedValues(Map<String, Object> namedValues) {
		put(PARAM_CQN_NAME_VALUES, namedValues);
	}

	// OUT
	public Result getResult() {
		return (Result)get(PARAM_RESULT);
	}

	public void setResult(Iterable<? extends Map<String, ?>> result) {
		put(PARAM_RESULT, ResultUtils.convert(result));
		setCompleted();
	}

}

==> cds-services-impl-2.4.0-sources.jar: com/sap/cds/services/impl/draft/DraftReadEventContextImpl.java <==
/**************************************************************************
 * (C) 2019-2021 SAP SE or an SAP affiliate company. All rights reserved. *
 **************************************************************************/
package com.sap.cds.services.impl.draft;

import java.util.Map;

import com.sap.cds.Result;
import com.sap.cds.ql.cqn.CqnSelect;
import com.sap.cds.services.EventContext;
import com.sap.cds.services.draft.DraftReadEventContext;
import com.sap.cds.services.draft.DraftService;
import com.sap.cds.services.impl.EventContextDelegator;
import com.sap.cds.services.utils.ResultUtils;

/**
 * Implementation for specialized {@link EventContext} to be used for {@link DraftService#EVENT_DRAFT_READ}
 */
public class DraftReadEventContextImpl extends EventContextDelegator implements DraftReadEventContext {

	public DraftReadEventContextImpl(EventContext eventContext) {
		super(eventContext);
	}

	@Override
	public DraftService getService() {
		return (DraftService) super.getService();
	}

	private static final String PARAM_CQN = "cqn";
	private static final String PARAM_CQN_NAME_VALUES = "cqnNamedValues";
	private static final String PARAM_RESULT = "result";

	// IN
	public CqnSelect getCqn() {
		return (CqnSelect)get(PARAM_CQN);
	}

	public void setCqn(CqnSelect cqn) {
		put(PARAM_CQN, cqn);
	}

	@SuppressWarnings("unchecked")
	public Map<String, Object> getCqnNamedValues(){
		return (Map<String,Object>)get(PARAM_CQN_NAME_VALUES);
	}

	public void setCqnNamedValues(Map<String, Object> namedValues) {
		put(PARAM_CQN_NAME_VALUES, namedValues);
	}

	// OUT
	public Result getResult() {
		return (Result)get(PARAM_RESULT);
	}

	public void setResult(Iterable<? extends Map<String, ?>> result) {
		put(PARAM_RESULT, ResultUtils.convert(result));
		setCompleted();
	}

}
